@@ -62,7 +62,7 @@ ImageTags = {
         ImageTags.hyphen = jQuery('#imagetags-hyphen').text();
         ImageTags.saveButton = form.find('input.submit-widget').hide().addClass('allowMultiSubmit').val()
         // Bind click event to a.tag-link-plain to disable real links
-        ImageTags.preventRealLink(jQuery('.tag-link-plain'));
+        ImageTags.preventRealLink(jQuery('.tag-link-plain'));     
     },
     
     
@@ -227,9 +227,11 @@ ImageTags = {
         event.preventDefault();
         event.stopPropagation();
         // Call to confirm dialog
-        var confirmDiv = jQuery('#imagetags-confirm-remove');
-        var yes = confirmDiv.find('span').first().text();
-        var no = confirmDiv.find('span').last().text()
+        var confirmContainer = jQuery('#imagetags-confirm-remove-wrapper')
+        var confirmDiv = confirmContainer.find('#imagetags-confirm-remove');
+        
+        var yes = confirmContainer.find('span').first().text();
+        var no = confirmContainer.find('span').last().text()
         var buttons = {}
         buttons[no] = function() {
             jQuery(this).dialog('close');
@@ -239,7 +241,7 @@ ImageTags = {
             jQuery.get(event.target.href + '&ajax:int=1', ImageTags.onRemoveSuccess);
         };
         confirmDiv.dialog({
-            title: confirmDiv.find('em').text(), 
+            title: confirmContainer.find('em').text(), 
             resizable: false,
             buttons: buttons,
             modal: true
